import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ActionsOrganizationPermissionsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#allowed_actions ActionsOrganizationPermissions#allowed_actions}.
     *
     * @stability stable
     */
    readonly allowedActions?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#enabled_repositories ActionsOrganizationPermissions#enabled_repositories}.
     *
     * @stability stable
     */
    readonly enabledRepositories: string;
    /**
     * allowed_actions_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#allowed_actions_config ActionsOrganizationPermissions#allowed_actions_config}
     *
     * @stability stable
     */
    readonly allowedActionsConfig?: ActionsOrganizationPermissionsAllowedActionsConfig;
    /**
     * enabled_repositories_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#enabled_repositories_config ActionsOrganizationPermissions#enabled_repositories_config}
     *
     * @stability stable
     */
    readonly enabledRepositoriesConfig?: ActionsOrganizationPermissionsEnabledRepositoriesConfig;
}
/**
 * @stability stable
 */
export interface ActionsOrganizationPermissionsAllowedActionsConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#github_owned_allowed ActionsOrganizationPermissions#github_owned_allowed}.
     *
     * @stability stable
     */
    readonly githubOwnedAllowed: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#patterns_allowed ActionsOrganizationPermissions#patterns_allowed}.
     *
     * @stability stable
     */
    readonly patternsAllowed?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#verified_allowed ActionsOrganizationPermissions#verified_allowed}.
     *
     * @stability stable
     */
    readonly verifiedAllowed?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class ActionsOrganizationPermissionsAllowedActionsConfigOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _githubOwnedAllowed?;
    /**
     * @stability stable
     */
    get githubOwnedAllowed(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set githubOwnedAllowed(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get githubOwnedAllowedInput(): boolean | cdktf.IResolvable | undefined;
    private _patternsAllowed?;
    /**
     * @stability stable
     */
    get patternsAllowed(): string[] | undefined;
    /**
     * @stability stable
     */
    set patternsAllowed(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetPatternsAllowed(): void;
    /**
     * @stability stable
     */
    get patternsAllowedInput(): string[] | undefined;
    private _verifiedAllowed?;
    /**
     * @stability stable
     */
    get verifiedAllowed(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set verifiedAllowed(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetVerifiedAllowed(): void;
    /**
     * @stability stable
     */
    get verifiedAllowedInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface ActionsOrganizationPermissionsEnabledRepositoriesConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html#repository_ids ActionsOrganizationPermissions#repository_ids}.
     *
     * @stability stable
     */
    readonly repositoryIds: number[];
}
/**
 * @stability stable
 */
export declare class ActionsOrganizationPermissionsEnabledRepositoriesConfigOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _repositoryIds?;
    /**
     * @stability stable
     */
    get repositoryIds(): number[];
    /**
     * @stability stable
     */
    set repositoryIds(value: number[]);
    /**
     * @stability stable
     */
    get repositoryIdsInput(): number[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html github_actions_organization_permissions}.
 *
 * @stability stable
 */
export declare class ActionsOrganizationPermissions extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/github/r/actions_organization_permissions.html github_actions_organization_permissions} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ActionsOrganizationPermissionsConfig);
    private _allowedActions?;
    /**
     * @stability stable
     */
    get allowedActions(): string | undefined;
    /**
     * @stability stable
     */
    set allowedActions(value: string | undefined);
    /**
     * @stability stable
     */
    resetAllowedActions(): void;
    /**
     * @stability stable
     */
    get allowedActionsInput(): string | undefined;
    private _enabledRepositories?;
    /**
     * @stability stable
     */
    get enabledRepositories(): string;
    /**
     * @stability stable
     */
    set enabledRepositories(value: string);
    /**
     * @stability stable
     */
    get enabledRepositoriesInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _allowedActionsConfig?;
    private __allowedActionsConfigOutput;
    /**
     * @stability stable
     */
    get allowedActionsConfig(): ActionsOrganizationPermissionsAllowedActionsConfigOutputReference;
    /**
     * @stability stable
     */
    putAllowedActionsConfig(value: ActionsOrganizationPermissionsAllowedActionsConfig | undefined): void;
    /**
     * @stability stable
     */
    resetAllowedActionsConfig(): void;
    /**
     * @stability stable
     */
    get allowedActionsConfigInput(): ActionsOrganizationPermissionsAllowedActionsConfig | undefined;
    private _enabledRepositoriesConfig?;
    private __enabledRepositoriesConfigOutput;
    /**
     * @stability stable
     */
    get enabledRepositoriesConfig(): ActionsOrganizationPermissionsEnabledRepositoriesConfigOutputReference;
    /**
     * @stability stable
     */
    putEnabledRepositoriesConfig(value: ActionsOrganizationPermissionsEnabledRepositoriesConfig | undefined): void;
    /**
     * @stability stable
     */
    resetEnabledRepositoriesConfig(): void;
    /**
     * @stability stable
     */
    get enabledRepositoriesConfigInput(): ActionsOrganizationPermissionsEnabledRepositoriesConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
