import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RepositoryAutolinkReferenceConfig extends cdktf.TerraformMetaArguments {
    /**
     * This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_autolink_reference.html#key_prefix RepositoryAutolinkReference#key_prefix}
     *
     * @stability stable
     */
    readonly keyPrefix: string;
    /**
     * The repository name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_autolink_reference.html#repository RepositoryAutolinkReference#repository}
     *
     * @stability stable
     */
    readonly repository: string;
    /**
     * The template of the target URL used for the links;
     *
     * must be a valid URL and contain `<num>` for the reference number
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_autolink_reference.html#target_url_template RepositoryAutolinkReference#target_url_template}
     *
     * @stability stable
     */
    readonly targetUrlTemplate: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/github/r/repository_autolink_reference.html github_repository_autolink_reference}.
 *
 * @stability stable
 */
export declare class RepositoryAutolinkReference extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/github/r/repository_autolink_reference.html github_repository_autolink_reference} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RepositoryAutolinkReferenceConfig);
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _keyPrefix?;
    /**
     * @stability stable
     */
    get keyPrefix(): string;
    /**
     * @stability stable
     */
    set keyPrefix(value: string);
    /**
     * @stability stable
     */
    get keyPrefixInput(): string | undefined;
    private _repository?;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    get repositoryInput(): string | undefined;
    private _targetUrlTemplate?;
    /**
     * @stability stable
     */
    get targetUrlTemplate(): string;
    /**
     * @stability stable
     */
    set targetUrlTemplate(value: string);
    /**
     * @stability stable
     */
    get targetUrlTemplateInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
